@@ -30,9 +30,8 @@ sub validate_request {
       $exists = length $value if defined $value;
     }
     elsif ($in eq 'formData' and $type eq 'file') {
-      $value  = $c->req->upload($name);
+      $value = $c->req->upload($name);
       $exists = $value ? 1 : 0;
-      $value  = $value ? $value->slurp : undef;
     }
     else {
       $value  = $cache{$in} ||= $self->_extract_request_parameter($c, $in);
@@ -79,7 +78,7 @@ sub validate_response {
     }
   }
   else {
-    push @errors, $self->validate($data, {});
+    push @errors, JSON::Validator::E('/' => "No responses rules defined for status $status.");
   }
 
   return @errors;
